@@ -32,14 +32,15 @@
 #include "panel-profile.h"
 #include "panel-menu-bar.h"
 #include "panel-applet-frame.h"
+#include "panel-applets-manager.h"
 #include "panel-globals.h"
 #include "panel-util.h"
 
 typedef enum {
-	PANEL_ORIENT_UP    = GNOME_Vertigo_PANEL_ORIENT_UP,
-	PANEL_ORIENT_DOWN  = GNOME_Vertigo_PANEL_ORIENT_DOWN,
-	PANEL_ORIENT_LEFT  = GNOME_Vertigo_PANEL_ORIENT_LEFT,
-	PANEL_ORIENT_RIGHT = GNOME_Vertigo_PANEL_ORIENT_RIGHT
+	PANEL_ORIENT_UP,
+	PANEL_ORIENT_DOWN,
+	PANEL_ORIENT_LEFT,
+	PANEL_ORIENT_RIGHT,
 } PanelOrient;
 
 static GConfEnumStringPair panel_orient_map [] = {
@@ -167,6 +168,16 @@ panel_compatibility_map_panel_type_string (const char *str,
 	return TRUE;
 }
 
+enum {
+	PANEL_SIZE_XX_SMALL = 12,
+	PANEL_SIZE_X_SMALL  = 24,
+	PANEL_SIZE_SMALL    = 36,
+	PANEL_SIZE_MEDIUM   = 48,
+	PANEL_SIZE_LARGE    = 64,
+	PANEL_SIZE_X_LARGE  = 80,
+	PANEL_SIZE_XX_LARGE = 128
+};
+
 static GConfEnumStringPair panel_size_map [] = {
 	{ PANEL_SIZE_XX_SMALL, "panel-size-xx-small" },
 	{ PANEL_SIZE_X_SMALL,  "panel-size-x-small" },
@@ -526,7 +537,7 @@ panel_compatibility_migrate_menu_panel_settings (GConfClient *client,
 	g_free (id);
 
 	/* window menu on far left corner */
-        id = panel_profile_prepare_object_with_id (PANEL_OBJECT_BONOBO, toplevel_id, 0, TRUE);
+        id = panel_profile_prepare_object_with_id (PANEL_OBJECT_APPLET, toplevel_id, 0, TRUE);
 
 	key = panel_gconf_full_key (PANEL_GCONF_APPLETS, id, "bonobo_iid");
         gconf_client_set_string (client, key, "OAFIID:GNOME_WindowMenuApplet", NULL);
@@ -978,7 +989,7 @@ copy_gconf_dir (GConfClient  *client,
 		if (entry->value)
 			gconf_client_set (client, key, entry->value, NULL);
 
-		gconf_entry_free (entry);
+		gconf_entry_unref (entry);
 	}
 	g_slist_free (list);
 
@@ -1070,7 +1081,7 @@ panel_compatibility_migrate_applications_scheme (GConfClient *client,
 }
 
 void
-panel_compatiblity_migrate_screenshot_action (GConfClient *client,
+panel_compatibility_migrate_screenshot_action (GConfClient *client,
 					      const char  *id)
 {
 	const char *key;
@@ -1089,3 +1100,68 @@ panel_compatiblity_migrate_screenshot_action (GConfClient *client,
 
 	panel_profile_add_to_list (PANEL_GCONF_OBJECTS, id);
 }
+
+gchar *
+panel_compatibility_get_applet_iid (const gchar *id)
+{
+	GConfClient *client = panel_gconf_get_client ();
+	PanelAppletInfo *info;
+	const char *key;
+	gchar *applet_iid;
+	gboolean needs_migration;
+	const char *iid;
+
+	/*
+	 * There are two compatibility steps here:
+	 *
+	 * 1) we need to migrate from bonobo_iid to applet_iid if there's no
+	 *    value in the applet_iid key. Always.
+	 *
+	 * 2) we need to try to migrate the iid to a new iid. We can't assume
+	 *    that the fact that the applet_iid key was used mean anything
+	 *    since the value there could well be a bonobo iid.
+	 *    The reason we really have to try to migrate first is this case:
+	 *    if an applet was added with the bonobo iid but gets ported later
+	 *    to dbus, then the reference to the bonobo iid will only be valid
+	 *    as an old reference.
+	 *    And if migration fails, we just use the iid as it is.
+	 */
+
+	needs_migration = FALSE;
+
+	key = panel_gconf_full_key (PANEL_GCONF_APPLETS, id, "applet_iid");
+	applet_iid = gconf_client_get_string (client, key, NULL);
+
+	if (!applet_iid || !applet_iid[0]) {
+		needs_migration = TRUE;
+
+		key = panel_gconf_full_key (PANEL_GCONF_APPLETS, id, "bonobo_iid");
+		applet_iid = gconf_client_get_string (client, key, NULL);
+
+		if (!applet_iid || !applet_iid[0])
+			return NULL;
+	}
+
+	info = panel_applets_manager_get_applet_info_from_old_id (applet_iid);
+	if (!info)
+		info = panel_applets_manager_get_applet_info (applet_iid);
+
+	if (!info)
+		return NULL;
+
+	iid = panel_applet_info_get_iid (info);
+
+	/* migrate if the iid in the configuration is different than the real
+	 * iid that will get used */
+	if (!g_str_equal (iid, applet_iid))
+		needs_migration = TRUE;
+
+	g_free (applet_iid);
+
+	if (needs_migration) {
+		key = panel_gconf_full_key (PANEL_GCONF_APPLETS, id, "applet_iid");
+		gconf_client_set_string (client, key, iid, NULL);
+	}
+
+	return g_strdup (iid);
+}
