@@ -102,10 +102,14 @@ panel_push_window_busy (GtkWidget *window)
 	busy ++;
 
 	if (busy == 1) {
+		GdkWindow *win;
+
 		gtk_widget_set_sensitive (window, FALSE);
-		if (window->window != NULL) {
+
+		win = gtk_widget_get_window (window);
+		if (win != NULL) {
 			GdkCursor *cursor = gdk_cursor_new (GDK_WATCH);
-			gdk_window_set_cursor (window->window, cursor);
+			gdk_window_set_cursor (win, cursor);
 			gdk_cursor_unref (cursor);
 			gdk_flush ();
 		}
@@ -123,9 +127,14 @@ panel_pop_window_busy (GtkWidget *window)
 	busy --;
 
 	if (busy <= 0) {
+		GdkWindow *win;
+
 		gtk_widget_set_sensitive (window, TRUE);
-		if (window->window != NULL)
-			gdk_window_set_cursor (window->window, NULL);
+
+		win = gtk_widget_get_window (window);
+		if (win != NULL)
+			gdk_window_set_cursor (win, NULL);
+
 		g_object_set_data (G_OBJECT (window),
 				   "Panel:WindowBusy", NULL);
 	} else {
